@@ -706,9 +706,6 @@ eog_job_save_as_run (EogJob *ejob)
 	EogJobSaveAs *saveas_job;
 	GList *it;
 	guint n_images;
-	guint file_permissions = 00000;
-	guint permissions_mask = 00600;
-	GFileInfo *info;
 
 	g_return_if_fail (EOG_IS_JOB_SAVE_AS (ejob));
 
@@ -797,30 +794,6 @@ eog_job_save_as_run (EogJob *ejob)
 						     dest_info,
 						     &ejob->error);
 
-		/* get file permissions */
-		info = g_file_query_info (saveas_job->file,
-					  G_FILE_ATTRIBUTE_UNIX_MODE,
-					  G_FILE_QUERY_INFO_NONE,
-					  NULL,
-					  NULL);
-
-		/* if we can't retrieve file permission apply default */
-		if (info != NULL) {
-			file_permissions = g_file_info_get_attribute_uint32 (info,
-									     G_FILE_ATTRIBUTE_UNIX_MODE);
-			g_object_unref (info);
-		}
-
-		/* apply permission mask to file permissions */
-		file_permissions |= permissions_mask;
-
-		g_file_set_attribute_uint32 (saveas_job->file,
-					     G_FILE_ATTRIBUTE_UNIX_MODE,
-					     file_permissions,
-					     G_FILE_QUERY_INFO_NONE,
-					     NULL,
-					     NULL);
-
 		if (src_info)
 			g_object_unref (src_info);
 
